@@ -12,7 +12,7 @@
     <message>
         <location filename="../src/main.cpp" line="47"/>
         <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
-        <translation type="unfinished"/>
+        <translation>منتقي الألوان لديبين : أداة سريعة لإنتقاء الألوان على الشاشة ، ترميزات الألوان RGB و HEX  ، يمكن الحصول عليها وفقاً للون المختار ، حيث منطقة اختيار اللون هي مكان نقر المؤشر .</translation>
     </message>
     <message>
         <location filename="../src/main.cpp" line="69"/>
